@@ -23,12 +23,10 @@ class NotificationStack(Stack):
     '''
     This Stack ...
     '''
-    def __init__(self, scope: Construct, construct_id: str, pinpoint_app_name: str, apns_bundle_id: str, apns_certificate_path: str, apns_certificate_pw: str,  **kwargs) -> None:
+    def __init__(self, scope: Construct, construct_id: str, pinpoint_app_name: str, apns_bundle_id: str, apns_certificate: str, apns_private_key: str,  **kwargs) -> None:
         super().__init__(scope, construct_id, **kwargs)
 
-        pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name)
-
-        apns_certificate = get_apns_certificate(apns_certificate_path, apns_certificate_pw) 
+        pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name) 
 
         cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
             application_id=pinpoint_app.ref,
@@ -36,9 +34,9 @@ class NotificationStack(Stack):
             # the properties below are optional
             bundle_id=apns_bundle_id,
             certificate=apns_certificate,
-            default_authentication_method="certificate",
+            # default_authentication_method="certificate",
             enabled=True,
-            # private_key=apns_certificate,
+            private_key=apns_private_key,
             # team_id="teamId",
             # token_key="tokenKey",
             # token_key_id="tokenKeyId"
